@@ -19,12 +19,12 @@ def CaptureJob():
     issues = list(
         filter(
             checkPrerequsites,
-            ["CAPTURE_CONNECTION_STRING","CAPTURE_CONTAINER_NAME","JOB"],
+            ["CAPTURE_CONNECTION_STRING","CAPTURE_CONTAINER_NAME","TASK_ID"],
         )
     )
     if len(issues) > 0:
         raise Exception(f"Missing environment variables {issues}")
-        
+
     config = DotMap({
         "connectionString": os.environ.get("CAPTURE_CONNECTION_STRING"),
         "containerName": os.environ.get("CAPTURE_CONTAINER_NAME"),
@@ -33,7 +33,7 @@ def CaptureJob():
     print(config.containerName)
     fileservice =FileService(config)
 
-    job = os.environ.get("JOB")
+    job = os.environ.get("TASK_ID")
 
     now = datetime.now() 
     date_time = now.strftime("%Y%m%d_%H%M%S")    
